==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/ProjectSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ProjectSpecFluentImpl<A extends io.fabric8.openshift.api.model.ProjectSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ProjectSpecFluent<A>{
  public ProjectSpecFluentImpl() {
  }
  public ProjectSpecFluentImpl(io.fabric8.openshift.api.model.ProjectSpec instance) {
    this.withFinalizers(instance.getFinalizers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> finalizers = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToFinalizers(java.lang.Integer index,java.lang.String item) {
    if (this.finalizers == null) {this.finalizers = new java.util.ArrayList<java.lang.String>();}
    this.finalizers.add(index, item);
    return (A)this;
  }
  public A setToFinalizers(java.lang.Integer index,java.lang.String item) {
    if (this.finalizers == null) {this.finalizers = new java.util.ArrayList<java.lang.String>();}
    this.finalizers.set(index, item); return (A)this;
  }
  public A addToFinalizers(java.lang.String... items) {
    if (this.finalizers == null) {this.finalizers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.finalizers.add(item);} return (A)this;
  }
  public A addAllToFinalizers(java.util.Collection<java.lang.String> items) {
    if (this.finalizers == null) {this.finalizers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.finalizers.add(item);} return (A)this;
  }
  public A removeFromFinalizers(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.finalizers!= null){ this.finalizers.remove(item);}} return (A)this;
  }
  public A removeAllFromFinalizers(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.finalizers!= null){ this.finalizers.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getFinalizers() {
    return this.finalizers;
  }
  public java.lang.String getFinalizer(java.lang.Integer index) {
    return this.finalizers.get(index);
  }
  public java.lang.String getFirstFinalizer() {
    return this.finalizers.get(0);
  }
  public java.lang.String getLastFinalizer() {
    return this.finalizers.get(finalizers.size() - 1);
  }
  public java.lang.String getMatchingFinalizer(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: finalizers) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingFinalizer(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: finalizers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withFinalizers(java.util.List<java.lang.String> finalizers) {
    if (finalizers != null) {this.finalizers = new java.util.ArrayList<java.lang.String>(); for (java.lang.String item : finalizers){this.addToFinalizers(item);}} else { this.finalizers = null;} return (A) this;
  }
  public A withFinalizers(java.lang.String... finalizers) {
    if (this.finalizers != null) {this.finalizers.clear();}
    if (finalizers != null) {for (java.lang.String item :finalizers){ this.addToFinalizers(item);}} return (A) this;
  }
  public java.lang.Boolean hasFinalizers() {
    return finalizers != null && !finalizers.isEmpty();
  }
  public A addNewFinalizer(java.lang.String arg0) {
    return (A)addToFinalizers(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProjectSpecFluentImpl that = (ProjectSpecFluentImpl) o;
    if (finalizers != null ? !finalizers.equals(that.finalizers) :that.finalizers != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(finalizers,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-5.12.3-sources.jar: io/fabric8/openshift/api/model/ProjectSpecFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class ProjectSpecFluentImpl<A extends io.fabric8.openshift.api.model.ProjectSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.ProjectSpecFluent<A>{
  public ProjectSpecFluentImpl() {
  }
  public ProjectSpecFluentImpl(io.fabric8.openshift.api.model.ProjectSpec instance) {
    this.withFinalizers(instance.getFinalizers()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.util.List<java.lang.String> finalizers = new java.util.ArrayList<java.lang.String>();
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public A addToFinalizers(java.lang.Integer index,java.lang.String item) {
    if (this.finalizers == null) {this.finalizers = new java.util.ArrayList<java.lang.String>();}
    this.finalizers.add(index, item);
    return (A)this;
  }
  public A setToFinalizers(java.lang.Integer index,java.lang.String item) {
    if (this.finalizers == null) {this.finalizers = new java.util.ArrayList<java.lang.String>();}
    this.finalizers.set(index, item); return (A)this;
  }
  public A addToFinalizers(java.lang.String... items) {
    if (this.finalizers == null) {this.finalizers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.finalizers.add(item);} return (A)this;
  }
  public A addAllToFinalizers(java.util.Collection<java.lang.String> items) {
    if (this.finalizers == null) {this.finalizers = new java.util.ArrayList<java.lang.String>();}
    for (java.lang.String item : items) {this.finalizers.add(item);} return (A)this;
  }
  public A removeFromFinalizers(java.lang.String... items) {
    for (java.lang.String item : items) {if (this.finalizers!= null){ this.finalizers.remove(item);}} return (A)this;
  }
  public A removeAllFromFinalizers(java.util.Collection<java.lang.String> items) {
    for (java.lang.String item : items) {if (this.finalizers!= null){ this.finalizers.remove(item);}} return (A)this;
  }
  public java.util.List<java.lang.String> getFinalizers() {
    return this.finalizers;
  }
  public java.lang.String getFinalizer(java.lang.Integer index) {
    return this.finalizers.get(index);
  }
  public java.lang.String getFirstFinalizer() {
    return this.finalizers.get(0);
  }
  public java.lang.String getLastFinalizer() {
    return this.finalizers.get(finalizers.size() - 1);
  }
  public java.lang.String getMatchingFinalizer(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: finalizers) { if(predicate.test(item)){ return item;} } return null;
  }
  public java.lang.Boolean hasMatchingFinalizer(java.util.function.Predicate<java.lang.String> predicate) {
    for (java.lang.String item: finalizers) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withFinalizers(java.util.List<java.lang.String> finalizers) {
    if (finalizers != null) {this.finalizers = new java.util.ArrayList(); for (java.lang.String item : finalizers){this.addToFinalizers(item);}} else { this.finalizers = null;} return (A) this;
  }
  public A withFinalizers(java.lang.String... finalizers) {
    if (this.finalizers != null) {this.finalizers.clear();}
    if (finalizers != null) {for (java.lang.String item :finalizers){ this.addToFinalizers(item);}} return (A) this;
  }
  public java.lang.Boolean hasFinalizers() {
    return finalizers != null && !finalizers.isEmpty();
  }
  public A addNewFinalizer(java.lang.String arg0) {
    return (A)addToFinalizers(new String(arg0));
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ProjectSpecFluentImpl that = (ProjectSpecFluentImpl) o;
    if (finalizers != null ? !finalizers.equals(that.finalizers) :that.finalizers != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(finalizers,  additionalProperties,  super.hashCode());
  }
  
}
